@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
 
-import os
-import re
-from .cache_utils import cpickle_cache, cached_property
-current_dir = os.path.dirname(os.path.realpath(__file__))
-
-from singleton import singleton
+import os, re
+from .cache_utils import cpickle_cache
+from ._current_dir import current_dir
+from .design_pattern import singleton ,cached_property
 
 @singleton()
 class LazyData(object):
@@ -26,28 +24,37 @@ class LazyData(object):
         检查 2个字符 的字符组 是否是正常单词 或 词组
         e.g. `"At" in two_length_words`
         """
-        def load__two_length_words__func():
-            import nltk
+        return self.nltk_abc_data[0]
+
+    @cached_property
+    def regular_words(self): return self.nltk_abc_data[1]
+
+    @cached_property
+    def nltk_abc_data(self):
+        nltk = self.nltk_download('abc')
+        def load__nltk_abc_data__func():
             import marisa_trie
-            return marisa_trie.Trie( \
+            from .regexp_utils import regexp
+            words = nltk.corpus.abc.words()
+
+            two_length_words_data = marisa_trie.Trie( \
                         sorted( \
                         list( \
                         set(\
-                            [w1 for w1 in nltk.corpus.abc.words() \
+                            [w1 for w1 in words \
                                 if (len(w1) == 2) and \
                                     re.compile("[a-z]", re.IGNORECASE).match(w1[0]) \
                             ] \
                         ))))
 
+            regular_words_data = marisa_trie.Trie([ \
+                    unicode(w1) for w1 in words if regexp.word.match(w1)])
 
-        return cpickle_cache(current_dir + "/two_length_words.cPickle", load__two_length_words__func)
+            return [two_length_words_data, regular_words_data]
+
+        return cpickle_cache(current_dir + "/nltk_abc.cPickle", \
+                load__nltk_abc_data__func, True)
 
-    @cached_property
-    def regular_words(self):
-        import nltk
-        import marisa_trie
-        from .regexp import word_regexp
-        return marisa_trie.Trie([unicode(w1) for w1 in nltk.corpus.abc.words() if word_regexp.match(w1)])
 
     @cached_property
     def lemmatize(self):
@@ -62,8 +69,8 @@ class LazyData(object):
 
         http://stackoverflow.com/questions/771918/how-do-i-do-word-stemming-or-lemmatization
         """
-        from nltk.stem.wordnet import WordNetLemmatizer
-        lmtzr = WordNetLemmatizer()
+        nltk = self.nltk_download('wordnet')
+        lmtzr = nltk.stem.wordnet.WordNetLemmatizer()
 
         def func(word1, tag1=None):
             if tag1 is None:
@@ -74,9 +81,18 @@ class LazyData(object):
 
     @cached_property
     def tagged_words__dict(self):
-        import nltk
+        nltk = self.nltk_download('brown')
         return {w1:t1.upper() for w1, t1 in nltk.corpus.brown.tagged_words()}
 
+    def nltk_download(self, package):
+        import nltk
+        if nltk.data.path[0] != current_dir:
+            nltk.data.path.insert(0, current_dir)
+
+        if not os.path.isdir(os.path.join(current_dir, 'corpora', package)):
+            nltk.download(info_or_id=package, download_dir=current_dir)
+        return nltk
+
 
 
 ld = LazyData()
